#define _GNU_SOURCE
#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <dirent.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <fcntl.h>
#include "uhumenu.h"

static char buf[256];

char *get_value (const struct item *item, const char *key)
{
	struct key_value *kp = item->keys_values;
	while (kp != NULL) {
		if (!strcmp(kp->key, key)) {
			return kp->value;
		}
		kp = kp->next;
	}
	return NULL;
}

char *get_name_lang (const struct item *item, const char *lang)
{
	char buf[32];
	char *s;

	sprintf(buf, "Name[%s]", lang);
	s = get_value(item, buf);
	if (s != NULL) return s;
	s = get_value(item, "Name");
	if (s != NULL) return s;
	return "";
}

char *get_name_locale (const struct item *item, const char *lang, iconv_t ic)
{
	char *s = get_name_lang(item, lang);
	char *d = buf;
	size_t slen = strlen(s);
	size_t dlen = 300;
	iconv(ic, &s, &slen, &d, &dlen);
	iconv(ic, NULL, NULL, NULL, NULL);
	*d = 0;
	return buf;
}

int empty_dir (const char *path)
{
	int fd;
	DIR *d;
	struct dirent *de;
	struct stat st;
	int error = 0;

	fd = open(".", O_RDONLY);
	if (fd < 0) {
		return -1;
	}
	if (chdir(path) < 0) {
		close(fd);
		return -1;
	}
	if ((d = opendir(".")) == NULL) {
		fchdir(fd);
		close(fd);
		return -1;
	}
	while ((de = readdir(d)) != NULL) {
		if (!strcmp(de->d_name, "." )) continue;
		if (!strcmp(de->d_name, "..")) continue;
		if (lstat(de->d_name, &st) < 0) {
			error = 1;
			continue;
		}
		if (S_ISDIR(st.st_mode)) {
			if (empty_dir(de->d_name) < 0) error = 1;
			if (rmdir(de->d_name) < 0) error = 1;
		} else {
			if (unlink(de->d_name) < 0) error = 1;
		}
	}
	closedir(d);
	fchdir(fd);
	close(fd);
	if (error) return -1;
	return 0;
}
